@@ -2,16 +2,19 @@
 # -----------------------------------------------------------------------------
 #
 #  Nes by Skriptke
-#  Copyright 2009 - 2010 Enrique F. Castañón
+#  Copyright 2009 - 2010 Enrique F. Castañón Barbero
 #  Licensed under the GNU GPL.
 #
+#  CPAN:
+#  http://search.cpan.org/dist/Nes/
+#
 #  Sample:
 #  http://nes.sourceforge.net/
 #
 #  Repository:
 #  http://github.com/Skriptke/nes
 # 
-#  Version 1.00_04
+#  Version 1.01
 #
 #  Nes.pm
 #
@@ -23,7 +26,7 @@ use strict;
 # cgi environment no defined in command line
 no warnings 'uninitialized';
 
-our $VERSION          = '1.00_04';
+our $VERSION          = '1.01.1_01';
 our $CRLF             = "\015\012";
 our $MAX_INTERACTIONS = 500;
 our $MOD_PERL         = $ENV{'MOD_PERL'} || 0;
@@ -1846,6 +1849,8 @@ use Nes::Singleton;
     my $self  = shift;
     my ($value, @security_options) = @_;
 
+    return $value if $value =~ /^\d*$/;
+
     my $tmp_no_html = $self->{'security_options'}{'no_html'};
     my $tmp_no_nes  = $self->{'security_options'}{'no_nes'};
     my $tmp_no_br   = $self->{'security_options'}{'no_br'};
@@ -1908,7 +1913,7 @@ use Nes::Singleton;
   sub replace_var {
     my $self  = shift;
     my ($var, @security_options) = @_;
- 
+
     return $self->security( $self->{'tags'}{$var}, @security_options );
   }
 
